;*******************************************************************************
; initialization
;*******************************************************************************
		
Start:

	move.w	#$2700,sr		; disable interrupts

SecurityCheck:
	move.b	(REG_HWVERSION),d0	; get the hardware version
	andi.b	#$0F,d0				; the last four bits contains the version
	beq.b	SkipSecurity		; skip the next instruction on v1 hardware
	move.l	#'SEGA',(REG_TMS)	; otherwise copy 'SEGA' to TMS register
SkipSecurity:

InitVDP:
	lea	(VDPInitDataStart),a0	; load the address of the VDP init data to a0
	move.w	#(VDPInitDataEnd-VDPInitDataStart)/2,d1	; length of init data to d1
InitVDPDataLoop:
	move.w	(a0)+,(VDP_CONTROL)	; write the init data
	dbf	d1,InitVDPDataLoop		; decrement value of d1 and loop if not 0

ClearCRAM:
	move.l	#VDP_CRAM_WRITE,(VDP_CONTROL); set VDP ctrl to CRAM write
	move.w	#$003f,d1	; 3f = 63 = (64 palettes in CRAM - 1)
ClearCRAMLoop:
	move.w	#$0000,(VDP_DATA)
	dbf	d1,ClearCRAMLoop

; clear VRAM - prevents garbage tiles from showing at boot on clone systems
	bsr.w	ClearVRAM	; clear VRAM

ClearRAM:
	lea	MEM_START,a0
	move.w	#(MEM_END-MEM_START),d1
ClearRAMLoop:
	and.l	#$00000000,(a0)+
	dbf	d1,ClearRAMLoop

InitController:
	move.b	#$40,(CTRL_1_CONTROL)
	; --------------------------------------------------------------------------
	; This attempts to figure out what type of controller is connected
	; This is based off documentation provided by Sega to Genesis developers
	; Modified to also check whether a 6-button controller is present
	; --------------------------------------------------------------------------
	lea	CTRL_1_DATA,a0		; load address to read controller 1 data
	;---------------------------------
	; set counter to 1 + TH high
	;---------------------------------
	move.b	#$40,(a0)
	nop
	nop
	move.b	(a0),(MEM_DEBUG_CYCLE1_INIT)
	;---------------------------------
	; set counter to 2 + TH low
	;---------------------------------
	move.b	(a0),d0
	move.b	#$00,(a0)
	nop
	nop
	move.b	(a0),d1
	move.b	d1,(MEM_DEBUG_CYCLE2_INIT)
	;---------------------------------
	; set counter to 3 + TH high
	;---------------------------------
	move.b	#$40,(a0)
	nop
	nop
	move.b	(a0),(MEM_DEBUG_CYCLE3_INIT)
	move.w	d0,d2
	lsr.b	#1,d0
	ror.w	#1,d0
	lsr.b	#1,d0
	rol.w	#1,d0
	ror.w	#1,d2
	lsr.b	#1,d2
	rol.w	#1,d2
	or.b	d2,d0
	and.w	#$03,d0
	lsl.b	#2,d0
	move.w	d1,d2
	lsr.b	#1,d1
	ror.w	#1,d1
	lsr.b	#1,d1
	rol.w	#1,d1
	ror.w	#1,d2
	lsr.b	#1,d2
	rol.w	#1,d2
	or.b	d2,d1
	and.w	#$03,d1
	or.b	d1,d0
	; -------------------------------------	
	; save the controller id
	; -------------------------------------	
	move.b	d0,(MEM_CONTROL_1_ID)
	;---------------------------------
	; set counter to 4 + TH low
	;---------------------------------
	move.b	#$00,(a0)	; set TH low
	nop					; bus synchronization
	nop					; bus synchronization
	move.b	(a0),(MEM_DEBUG_CYCLE4_INIT)
	;---------------------------------
	; set counter to 5 + TH high
	;---------------------------------	
	move.b	#$40,(a0)	; set TH high
	nop					; bus synchronization
	nop					; bus synchronization
	move.b	(a0),(MEM_DEBUG_CYCLE5_INIT)
	;---------------------------------
	; set counter to 6 + TH low
	; 6 button id is in counter 6
	;---------------------------------	
	move.b	#$00,(a0)	; set TH low
	nop					; bus synchronization
	nop					; bus synchronization
	move.b	(a0),d0	; copy controller data to d0
	move.b	d0,(MEM_DEBUG_CYCLE6_INIT)
	cmpi.b	#%00110011,d0
	beq.s	.1
	move.b	#%111111,(MEM_CONTROL_1_6BUTTON)
.1
	;---------------------------------
	; set counter to 7 + TH high
	;---------------------------------	
	move.b	#$40,(a0)	; set TH high
	nop					; bus synchronization
	nop					; bus synchronization
	move.b	(a0),(MEM_DEBUG_CYCLE7_INIT)

	;---------------------------------
	; set counter to 8 + TH low
	;---------------------------------
	move.b	#$00,(a0)	; set TH low
	nop					; bus synchronization
	nop					; bus synchronization
	move.b	(a0),(MEM_DEBUG_CYCLE8_INIT)
	;---------------------------------
	; set counter to 9 + TH high
	;---------------------------------	
	move.b	#$40,(a0)	; set TH high
	nop					; bus synchronization
	nop					; bus synchronization
	move.b	(a0),(MEM_DEBUG_CYCLE9_INIT)


	move.w	#$2000,sr		; re-enable interrupts
